@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "face-explorer" "0.0.6"
+(define-package "face-explorer" "20250117.932"
   "Tools for faces and text properties."
   ()
   :url "https://github.com/Lindydancer/face-explorer"
